@@ -28,7 +28,9 @@ from ._format import (
     token_credential_output_format,
     agentpool_output_format,
     connected_registry_output_format,
-    connected_registry_list_output_format
+    connected_registry_list_output_format,
+    list_referrers_output_format,
+    manifest_output_format,
 )
 from ._client_factory import (
     cf_acr_registries,
@@ -46,7 +48,9 @@ from ._client_factory import (
 )
 
 
-def load_command_table(self, _):  # pylint: disable=too-many-statements
+# pylint: disable=too-many-locals
+# pylint: disable=too-many-statements
+def load_command_table(self, _):
 
     acr_custom_util = CliCommandType(
         operations_tmpl='azure.cli.command_modules.acr.custom#{}',
@@ -79,6 +83,10 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
         operations_tmpl='azure.cli.command_modules.acr.repository#{}'
     )
 
+    acr_manifest_util = CliCommandType(
+        operations_tmpl='azure.cli.command_modules.acr.manifest#{}'
+    )
+
     acr_webhook_util = CliCommandType(
         operations_tmpl='azure.cli.command_modules.acr.webhook#{}',
         table_transformer=webhook_output_format,
@@ -197,12 +205,24 @@ def load_command_table(self, _):  # pylint: disable=too-many-statements
     with self.command_group('acr repository', acr_repo_util) as g:
         g.command('list', 'acr_repository_list')
         g.command('show-tags', 'acr_repository_show_tags')
-        g.command('show-manifests', 'acr_repository_show_manifests')
+        g.command('show-manifests', 'acr_repository_show_manifests',
+                  deprecate_info=self.deprecate(redirect='acr manifest metadata list', hide=True))
         g.show_command('show', 'acr_repository_show')
         g.command('update', 'acr_repository_update')
         g.command('delete', 'acr_repository_delete')
         g.command('untag', 'acr_repository_untag')
 
+    with self.command_group('acr manifest', acr_manifest_util, is_preview=True) as g:
+        g.show_command('show', 'acr_manifest_show')
+        g.command('list', 'acr_manifest_list', table_transformer=manifest_output_format)
+        g.command('delete', 'acr_manifest_delete')
+        g.command('list-referrers', 'acr_manifest_list_referrers', table_transformer=list_referrers_output_format)
+
+    with self.command_group('acr manifest metadata', acr_manifest_util, is_preview=True) as g:
+        g.show_command('show', 'acr_manifest_metadata_show')
+        g.command('list', 'acr_manifest_metadata_list')
+        g.command('update', 'acr_manifest_metadata_update')
+
     with self.command_group('acr webhook', acr_webhook_util) as g:
         g.command('list', 'acr_webhook_list')
         g.command('create', 'acr_webhook_create')
