@@ -14,6 +14,10 @@ CONST_SCALE_SET_PRIORITY_SPOT = "Spot"
 CONST_SPOT_EVICTION_POLICY_DELETE = "Delete"
 CONST_SPOT_EVICTION_POLICY_DEALLOCATE = "Deallocate"
 
+# Scale Down Mode
+CONST_SCALE_DOWN_MODE_DELETE = "Delete"
+CONST_SCALE_DOWN_MODE_DEALLOCATE = "Deallocate"
+
 # node os disk type
 CONST_OS_DISK_TYPE_MANAGED = "Managed"
 CONST_OS_DISK_TYPE_EPHEMERAL = "Ephemeral"
