@@ -2,8 +2,6 @@
 # Copyright (c) Microsoft Corporation. All rights reserved.
 # Licensed under the MIT License. See License.txt in the project root for license information.
 # --------------------------------------------------------------------------------------------
-
-import datetime
 import json
 
 from azure.cli.core.azclierror import (
@@ -479,100 +477,6 @@ def ensure_container_insights_for_monitoring(
             else:
                 raise error
 
-    else:
-        # legacy auth with LA workspace solution
-        unix_time_in_millis = int(
-            (
-                datetime.datetime.utcnow() -
-                datetime.datetime.utcfromtimestamp(0)
-            ).total_seconds() * 1000.0
-        )
-
-        solution_deployment_name = "ContainerInsights-{}".format(
-            unix_time_in_millis
-        )
-
-        # pylint: disable=line-too-long
-        template = {
-            "$schema": "https://schema.management.azure.com/schemas/2015-01-01/deploymentTemplate.json#",
-            "contentVersion": "1.0.0.0",
-            "parameters": {
-                "workspaceResourceId": {
-                    "type": "string",
-                    "metadata": {
-                        "description": "Azure Monitor Log Analytics Resource ID"
-                    },
-                },
-                "workspaceRegion": {
-                    "type": "string",
-                    "metadata": {
-                        "description": "Azure Monitor Log Analytics workspace region"
-                    },
-                },
-                "solutionDeploymentName": {
-                    "type": "string",
-                    "metadata": {
-                        "description": "Name of the solution deployment"
-                    },
-                },
-            },
-            "resources": [
-                {
-                    "type": "Microsoft.Resources/deployments",
-                    "name": "[parameters('solutionDeploymentName')]",
-                    "apiVersion": "2017-05-10",
-                    "subscriptionId": "[split(parameters('workspaceResourceId'),'/')[2]]",
-                    "resourceGroup": "[split(parameters('workspaceResourceId'),'/')[4]]",
-                    "properties": {
-                        "mode": "Incremental",
-                        "template": {
-                            "$schema": "https://schema.management.azure.com/schemas/2015-01-01/deploymentTemplate.json#",
-                            "contentVersion": "1.0.0.0",
-                            "parameters": {},
-                            "variables": {},
-                            "resources": [
-                                {
-                                    "apiVersion": "2015-11-01-preview",
-                                    "type": "Microsoft.OperationsManagement/solutions",
-                                    "location": "[parameters('workspaceRegion')]",
-                                    "name": "[Concat('ContainerInsights', '(', split(parameters('workspaceResourceId'),'/')[8], ')')]",
-                                    "properties": {
-                                        "workspaceResourceId": "[parameters('workspaceResourceId')]"
-                                    },
-                                    "plan": {
-                                        "name": "[Concat('ContainerInsights', '(', split(parameters('workspaceResourceId'),'/')[8], ')')]",
-                                        "product": "[Concat('OMSGallery/', 'ContainerInsights')]",
-                                        "promotionCode": "",
-                                        "publisher": "Microsoft",
-                                    },
-                                }
-                            ],
-                        },
-                        "parameters": {},
-                    },
-                }
-            ],
-        }
-
-        params = {
-            "workspaceResourceId": {"value": workspace_resource_id},
-            "workspaceRegion": {"value": location},
-            "solutionDeploymentName": {"value": solution_deployment_name},
-        }
-
-        deployment_name = "aks-monitoring-{}".format(unix_time_in_millis)
-        # publish the Container Insights solution to the Log Analytics workspace
-        return _invoke_deployment(
-            cmd,
-            resource_group,
-            deployment_name,
-            template,
-            params,
-            validate=False,
-            no_wait=False,
-            subscription_id=subscription_id,
-        )
-
 
 def _invoke_deployment(
     cmd,
