@@ -10,8 +10,8 @@ import time
 
 from azure.cli.testsdk import ScenarioTest, JMESPathCheckExists, ResourceGroupPreparer, \
     StorageAccountPreparer, KeyVaultPreparer, record_only
-from azure.mgmt.recoveryservicesbackup.models import StorageType
-from azure_devtools.scenario_tests import AllowLargeResponse
+from azure.mgmt.recoveryservicesbackup.activestamp.models import StorageType
+from azure.cli.testsdk.scenario_tests import AllowLargeResponse
 
 from .preparers import VaultPreparer, VMPreparer, ItemPreparer, PolicyPreparer, RPPreparer
 
@@ -1074,8 +1074,3 @@ class BackupTests(ScenarioTest, unittest.TestCase):
             self.check('properties.useSystemAssignedIdentity', False),
             self.check('properties.lastUpdateStatus', 'Succeeded')
         ])
-
-        
-
-
-        
