@@ -6,6 +6,8 @@
 # pylint: disable=line-too-long
 # pylint: disable=too-many-lines
 # pylint: disable=inconsistent-return-statements
+# pylint: disable=too-many-locals
+
 from azure.cli.core.profiles import ResourceType
 
 
@@ -14,11 +16,13 @@ from azure.cli.core.profiles import ResourceType
 def cli_namespace_create(cmd, client, resource_group_name, namespace_name, location=None, tags=None, sku='Standard', capacity=None,
                          is_auto_inflate_enabled=None, maximum_throughput_units=None, is_kafka_enabled=None,
                          default_action=None, identity=None, zone_redundant=None, cluster_arm_id=None, trusted_service_access_enabled=None,
-                         disable_local_auth=None):
+                         disable_local_auth=None, mi_system_assigned=None, mi_user_assigned=None, encryption_config=None):
     EHNamespace = cmd.get_models('EHNamespace', resource_type=ResourceType.MGMT_EVENTHUB)
     Sku = cmd.get_models('Sku', resource_type=ResourceType.MGMT_EVENTHUB)
     Identity = cmd.get_models('Identity', resource_type=ResourceType.MGMT_EVENTHUB)
     IdentityType = cmd.get_models('ManagedServiceIdentityType', resource_type=ResourceType.MGMT_EVENTHUB)
+    UserAssignedIdentity = cmd.get_models('UserAssignedIdentity', resource_type=ResourceType.MGMT_EVENTHUB)
+    Encryption = cmd.get_models('Encryption', resource_type=ResourceType.MGMT_EVENTHUB)
 
     if cmd.supported_api_version(resource_type=ResourceType.MGMT_EVENTHUB, min_api='2018-01-01-preview'):
         ehparam = EHNamespace()
@@ -31,9 +35,26 @@ def cli_namespace_create(cmd, client, resource_group_name, namespace_name, locat
         ehparam.zone_redundant = zone_redundant
         ehparam.disable_local_auth = disable_local_auth
         ehparam.cluster_arm_id = cluster_arm_id
-        if identity:
+
+        if identity or mi_system_assigned:
             ehparam.identity = Identity(type=IdentityType.SYSTEM_ASSIGNED)
 
+        if mi_user_assigned:
+            if ehparam.identity:
+                if ehparam.identity.type == IdentityType.SYSTEM_ASSIGNED:
+                    ehparam.identity.type = IdentityType.SYSTEM_ASSIGNED_USER_ASSIGNED
+                else:
+                    ehparam.identity.type = IdentityType.USER_ASSIGNED
+            else:
+                ehparam.identity = Identity(type=IdentityType.USER_ASSIGNED)
+
+            default_user_identity = UserAssignedIdentity()
+            ehparam.identity.user_assigned_identities = dict.fromkeys(mi_user_assigned, default_user_identity)
+
+        if encryption_config:
+            ehparam.encryption = Encryption()
+            ehparam.encryption.key_vault_properties = encryption_config
+
         client.begin_create_or_update(
             resource_group_name=resource_group_name,
             namespace_name=namespace_name,
@@ -403,3 +424,138 @@ def reject_private_endpoint_connection(cmd, client, resource_group_name, namespa
         cmd, client, resource_group_name=resource_group_name, namespace_name=namespace_name, is_approved=False,
         private_endpoint_connection_name=private_endpoint_connection_name, description=description
     )
+
+
+def cli_add_identity(cmd, client, resource_group_name, namespace_name, system_assigned=None, user_assigned=None):
+    namespace = client.get(resource_group_name, namespace_name)
+    IdentityType = cmd.get_models('ManagedServiceIdentityType', resource_type=ResourceType.MGMT_EVENTHUB)
+    Identity = cmd.get_models('Identity', resource_type=ResourceType.MGMT_EVENTHUB)
+    UserAssignedIdentity = cmd.get_models('UserAssignedIdentity', resource_type=ResourceType.MGMT_EVENTHUB)
+
+    identity_id = {}
+
+    if namespace.identity is None:
+        namespace.identity = Identity()
+
+    if system_assigned:
+        if namespace.identity.type == IdentityType.USER_ASSIGNED:
+            namespace.identity.type = IdentityType.SYSTEM_ASSIGNED_USER_ASSIGNED
+
+        elif namespace.identity.type == IdentityType.NONE or namespace.identity.type is None:
+            namespace.identity.type = IdentityType.SYSTEM_ASSIGNED
+
+    if user_assigned:
+        default_user_identity = UserAssignedIdentity()
+        identity_id.update(dict.fromkeys(user_assigned, default_user_identity))
+
+        if namespace.identity.user_assigned_identities is None:
+            namespace.identity.user_assigned_identities = identity_id
+        else:
+            namespace.identity.user_assigned_identities.update(identity_id)
+
+        if namespace.identity.type == IdentityType.SYSTEM_ASSIGNED:
+            namespace.identity.type = IdentityType.SYSTEM_ASSIGNED_USER_ASSIGNED
+
+        elif namespace.identity.type == IdentityType.NONE or namespace.identity.type is None:
+            namespace.identity.type = IdentityType.USER_ASSIGNED
+
+    client.begin_create_or_update(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        parameters=namespace).result()
+
+    get_namespace = client.get(resource_group_name, namespace_name)
+
+    return get_namespace
+
+
+def cli_remove_identity(cmd, client, resource_group_name, namespace_name, system_assigned=None, user_assigned=None):
+    namespace = client.get(resource_group_name, namespace_name)
+    IdentityType = cmd.get_models('ManagedServiceIdentityType', resource_type=ResourceType.MGMT_EVENTHUB)
+
+    from azure.cli.core import CLIError
+
+    if namespace.identity is None:
+        raise CLIError('The namespace does not have identity enabled')
+
+    if system_assigned:
+        if namespace.identity.type == IdentityType.SYSTEM_ASSIGNED:
+            namespace.identity.type = IdentityType.NONE
+
+        if namespace.identity.type == IdentityType.SYSTEM_ASSIGNED_USER_ASSIGNED:
+            namespace.identity.type = IdentityType.USER_ASSIGNED
+
+    if user_assigned:
+        if namespace.identity.type == IdentityType.USER_ASSIGNED:
+            if namespace.identity.user_assigned_identities:
+                for x in user_assigned:
+                    namespace.identity.user_assigned_identities.pop(x)
+                # if all identities are popped off of the dictionary, we disable user assigned identity
+                if len(namespace.identity.user_assigned_identities) == 0:
+                    namespace.identity.type = IdentityType.NONE
+                    namespace.identity.user_assigned_identities = None
+
+        if namespace.identity.type == IdentityType.SYSTEM_ASSIGNED_USER_ASSIGNED:
+            if namespace.identity.user_assigned_identities:
+                for x in user_assigned:
+                    namespace.identity.user_assigned_identities.pop(x)
+                # if all identities are popped off of the dictionary, we disable user assigned identity
+                if len(namespace.identity.user_assigned_identities) == 0:
+                    namespace.identity.type = IdentityType.SYSTEM_ASSIGNED
+                    namespace.identity.user_assigned_identities = None
+
+    client.begin_create_or_update(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        parameters=namespace).result()
+
+    get_namespace = client.get(resource_group_name, namespace_name)
+
+    return get_namespace
+
+
+def cli_add_encryption(cmd, client, resource_group_name, namespace_name, encryption_config):
+    namespace = client.get(resource_group_name, namespace_name)
+    Encryption = cmd.get_models('Encryption', resource_type=ResourceType.MGMT_EVENTHUB)
+
+    if namespace.encryption:
+        if namespace.encryption.key_vault_properties:
+            namespace.encryption.key_vault_properties.extend(encryption_config)
+        else:
+            namespace.encryption.key_vault_properties = encryption_config
+
+    else:
+        namespace.encryption = Encryption()
+        namespace.encryption.key_vault_properties = encryption_config
+
+    client.begin_create_or_update(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        parameters=namespace).result()
+
+    get_namespace = client.get(resource_group_name, namespace_name)
+
+    return get_namespace
+
+
+def cli_remove_encryption(client, resource_group_name, namespace_name, encryption_config):
+    namespace = client.get(resource_group_name, namespace_name)
+
+    from azure.cli.core import CLIError
+
+    if namespace.encryption is None:
+        raise CLIError('The namespace does not have encryption enabled')
+
+    if namespace.encryption.key_vault_properties:
+        for encryption_property in encryption_config:
+            if encryption_property in namespace.encryption.key_vault_properties:
+                namespace.encryption.key_vault_properties.remove(encryption_property)
+
+    client.begin_create_or_update(
+        resource_group_name=resource_group_name,
+        namespace_name=namespace_name,
+        parameters=namespace).result()
+
+    get_namespace = client.get(resource_group_name, namespace_name)
+
+    return get_namespace
