@@ -64,13 +64,9 @@ class EHNamespaceCURDScenarioTest(ScenarioTest):
             checks=[self.check('sku.name', self.kwargs['sku'])])
 
         # Get Created Namespace list by subscription
-        listnamespaceresult = self.cmd('eventhubs namespace list').output
+        listnamespaceresult = self.cmd('eventhubs namespace list --resource-group {rg}').output
         self.assertGreater(len(listnamespaceresult), 0)
 
-        # Get Created Namespace list by ResourceGroup
-        listnamespacebyresourcegroupresult = self.cmd('eventhubs namespace list --resource-group {rg}').output
-        self.assertGreater(len(listnamespacebyresourcegroupresult), 0)
-
         # Create Authoriazation Rule
         self.cmd('eventhubs namespace authorization-rule create --resource-group {rg} --namespace-name {namespacename} --name {authoname} --rights {accessrights}',
                  checks=[self.check('name', self.kwargs['authoname'])])
