@@ -1113,15 +1113,79 @@ examples:
         az monitor log-analytics workspace table show --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable
 """
 
+helps['monitor log-analytics workspace table create'] = """
+type: command
+short-summary: Create a Log Analytics workspace microsoft/custom log table. The table name needs to end with '_CL'.
+examples:
+  - name: Create a Log Analytics workspace custom log table.
+    text: |
+        az monitor log-analytics workspace table create --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_CL --retention-time 45 --columns MyColumn1=string TimeGenerated=datetime
+"""
+
+helps['monitor log-analytics workspace table migrate'] = """
+type: command
+short-summary: Migrate a Log Analytics table from support of the Data Collector API and Custom Fields features to support of Data Collection Rule-based Custom Logs.
+examples:
+  - name: Migrate a Log Analytics workspace table.
+    text: |
+        az monitor log-analytics workspace table migrate --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_CL
+"""
+
+helps['monitor log-analytics workspace table search-job'] = """
+type: group
+short-summary: Manage tables for log analytics workspace search results table.
+"""
+
+helps['monitor log-analytics workspace table search-job create'] = """
+type: command
+short-summary: Create a Log Analytics workspace search results table. The table name needs to end with '_SRCH'.
+examples:
+  - name: Create a Log Analytics workspace search result table.
+    text: |
+        az monitor log-analytics workspace table search-job create --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_SRCH --retention-time 45 --search-query "Heartbeat | where SourceSystem != '' | project SourceSystem" --limit 1000 --start-search-time "Sat, 28 Aug 2021 05:29:18 GMT" --end-search-time "Sat, 28 Aug 2021 08:29:18 GMT"
+"""
+
+helps['monitor log-analytics workspace table restore'] = """
+type: group
+short-summary: Manage tables for log analytics workspace restore logs table.
+"""
+
+helps['monitor log-analytics workspace table restore create'] = """
+type: command
+short-summary: Create a Log Analytics workspace restore logs table. The table name needs to end with '_RST'.
+examples:
+  - name: Create a Log Analytics workspace restore logs table.
+    text: |
+        az monitor log-analytics workspace table restore create --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable_RST --start-restore-time "Sat, 28 Aug 2021 05:29:18 GMT" --end-restore-time "Sat, 28 Aug 2021 08:29:18 GMT" --restore-source-table MyTable
+"""
+
+
 helps['monitor log-analytics workspace table update'] = """
 type: command
-short-summary: Update the properties of a Log Analytics workspace table, currently only support updating retention time.
+short-summary: Update the properties of a Log Analytics workspace table.
 examples:
-  - name: Update the retention time of a Log Analytics workspace table
+  - name: Update the properties of a Log Analytics workspace table.
     text: |
         az monitor log-analytics workspace table update --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable --retention-time 30
 """
 
+helps['monitor log-analytics workspace table delete'] = """
+type: command
+short-summary: Delete a Log Analytics workspace table.
+examples:
+  - name: Delete a Log Analytics workspace table.
+    text: |
+        az monitor log-analytics workspace table delete --resource-group MyResourceGroup --workspace-name MyWorkspace -n MyTable
+"""
+
+helps['monitor log-analytics workspace table wait'] = """
+type: command
+short-summary: Place the CLI in a waiting state until a condition of the workspace table is met.
+examples:
+  - name: Pause executing next line of CLI script until the workspace table is successfully provisioned.
+    text: az monitor log-analytics workspace table wait -n MyTable -g MyResourceGroup --workspace-name MyWorkspace --created
+"""
+
 helps['monitor log-analytics workspace pack'] = """
 type: group
 short-summary: Manage intelligent packs for log analytics workspace.
@@ -1170,6 +1234,9 @@ examples:
     text: |
         az monitor log-analytics workspace update --resource-group myresourcegroup --retention-time 30 --workspace-name myworkspace
     crafted: true
+  - name: Update the defaultDataCollectionRuleResourceId of the workspace
+    text: |
+        az monitor log-analytics workspace update --resource-group myresourcegroup --workspace-name myworkspace --data-collection-rule "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Insights/dataCollectionRules/{dcrName}".
 """
 
 helps['monitor log-analytics workspace linked-service'] = """
