@@ -250,7 +250,7 @@ class TestLogProfileScenarios(ScenarioTest):
             self.check('publicNetworkAccessForQuery', 'Disabled')
         ])
 
-    @ResourceGroupPreparer(name_prefix='cli_test_monitor_workspace_recover', location='westus')
+    @ResourceGroupPreparer(name_prefix='cli_test_monitor_workspace_recover', location='WestEurope')
     @AllowLargeResponse()
     def test_monitor_log_analytics_workspace_recover(self, resource_group):
         workspace_name = self.create_random_name('clitest', 20)
@@ -272,10 +272,6 @@ class TestLogProfileScenarios(ScenarioTest):
             self.check('workspaceCapping.dailyQuotaGb', 2.0)
         ])
 
-        self.cmd("monitor log-analytics workspace table list -g {rg} --workspace-name {name}", checks=[
-            # self.check('length(@)', 0)
-        ])
-
         self.kwargs.update({
             'table_name': 'Syslog'
         })
@@ -284,35 +280,37 @@ class TestLogProfileScenarios(ScenarioTest):
             self.check('retentionInDays', 30)
         ])
 
-        self.cmd("monitor log-analytics workspace list-deleted-workspaces -g {rg}", checks=[
-            self.check('length(@)', 0)
-        ])
+        # not supported in api_version = 2021-12-01-preview
+        # self.cmd("monitor log-analytics workspace list-deleted-workspaces -g {rg}", checks=[
+        #     self.check('length(@)', 0)
+        # ])
 
         self.cmd("monitor log-analytics workspace delete -g {rg} -n {name} -y")
 
-        self.cmd("monitor log-analytics workspace list-deleted-workspaces -g {rg}", checks=[
-            self.check('length(@)', 1)
-        ])
+        # not supported in api_version = 2021-12-01-preview
+        # self.cmd("monitor log-analytics workspace list-deleted-workspaces -g {rg}", checks=[
+        #     self.check('length(@)', 1)
+        # ])
 
-        self.cmd("monitor log-analytics workspace recover -g {rg} -n {name}", checks=[
-            self.check('provisioningState', 'Succeeded'),
-            self.check('retentionInDays', 30),
-            self.check('sku.name', 'capacityreservation'),
-            self.check('sku.capacityReservationLevel', 200),
-            self.check('workspaceCapping.dailyQuotaGb', 2.0)
-        ])
+        # self.cmd("monitor log-analytics workspace recover -g {rg} -n {name}", checks=[
+        #     self.check('provisioningState', 'Succeeded'),
+        #     self.check('retentionInDays', 30),
+        #     self.check('sku.name', 'capacityreservation'),
+        #     self.check('sku.capacityReservationLevel', 200),
+        #     self.check('workspaceCapping.dailyQuotaGb', 2.0)
+        # ])
 
-        self.cmd("monitor log-analytics workspace show -g {rg} -n {name}", checks=[
-            self.check('provisioningState', 'Succeeded'),
-            self.check('retentionInDays', 30),
-            self.check('sku.name', 'capacityreservation'),
-            self.check('sku.capacityReservationLevel', 200),
-            self.check('workspaceCapping.dailyQuotaGb', 2.0)
-        ])
+        # self.cmd("monitor log-analytics workspace show -g {rg} -n {name}", checks=[
+        #     self.check('provisioningState', 'Succeeded'),
+        #     self.check('retentionInDays', 30),
+        #     self.check('sku.name', 'capacityreservation'),
+        #     self.check('sku.capacityReservationLevel', 200),
+        #     self.check('workspaceCapping.dailyQuotaGb', 2.0)
+        # ])
 
-        self.cmd("monitor log-analytics workspace list-deleted-workspaces -g {rg}", checks=[
-            self.check('length(@)', 0)
-        ])
+        # self.cmd("monitor log-analytics workspace list-deleted-workspaces -g {rg}", checks=[
+        #     self.check('length(@)', 0)
+        # ])
 
         self.cmd("monitor log-analytics workspace delete -g {rg} -n {name} --force -y")
 
@@ -478,3 +476,61 @@ class TestLogProfileScenarios(ScenarioTest):
         self.cmd('monitor log-analytics workspace data-export delete -g {rg} --workspace-name {workspace_name} -n {data_export_name} -y')
         with self.assertRaisesRegex(SystemExit, '3'):
             self.cmd('monitor log-analytics workspace data-export show -g {rg} --workspace-name {workspace_name} -n {data_export_name}')
+
+    @record_only()
+    def test_monitor_log_analytics_workspace_data_collection_rules(self):
+        self.kwargs.update({
+            'ws_name': 'wsn1',
+            'rule_name': 'rule11',
+            'rule_id': '/subscriptions/0b1f6471-1bf0-4dda-aec3-cb9272f09590/resourceGroups/tbtest/providers/Microsoft.Insights/dataCollectionRules/rule11'
+        })
+        # extension command
+        # rule = self.cmd('monitor data-collection rule show -g tbtest -n rule11').get_output_in_json()
+        # self.kwargs.update({
+        #     'rule_id': rule['id']
+        # })
+        self.cmd('monitor log-analytics workspace update -g tbtest -n {ws_name} --data-collection-rule {rule_id}', checks=[
+            # self.check('defaultDataCollectionRuleResourceId', '{rule_id}')
+        ])
+
+    @ResourceGroupPreparer(name_prefix='cli_test_monitor_workspace_table', location='WestEurope')
+    @AllowLargeResponse()
+    def test_monitor_log_analytics_workspace_table(self, resource_group):
+
+        self.kwargs.update({
+            'ws_name':self.create_random_name('ws-', 10),
+            'table_name': self.create_random_name('TB', 10) + '_CL',
+            'table2_name': self.create_random_name('TB', 10) + '_SRCH',
+        })
+
+        self.cmd('monitor log-analytics workspace create -g {rg} -n {ws_name}')
+        self.cmd('monitor log-analytics workspace table create -g {rg} -n {table_name} --workspace-name {ws_name} --retention-time 45 --total-retention-time 70 --plan Analytics --columns col1=guid TimeGenerated=datetime', checks=[
+            self.check('name', '{table_name}'),
+            self.check('retentionInDays', 45),
+            self.check('totalRetentionInDays', 70),
+            self.check('schema.columns[0].name', 'col1'),
+            self.check('schema.columns[0].type', 'guid'),
+            self.check('schema.columns[1].name', 'TimeGenerated'),
+            self.check('schema.columns[1].type', 'datetime'),
+        ])
+        self.cmd('monitor log-analytics workspace table update -g {rg} -n {table_name} --workspace-name {ws_name} --retention-time 50 --total-retention-time 80 --columns col2=guid', checks=[
+            self.check('name', '{table_name}'),
+            self.check('retentionInDays', 50),
+            self.check('totalRetentionInDays', 80),
+            self.check('schema.columns[0].name', 'col2'),
+            self.check('schema.columns[0].type', 'guid'),
+        ])
+        self.cmd('monitor log-analytics workspace table show -g {rg} -n {table_name} --workspace-name {ws_name}', checks=[
+            self.check('name', '{table_name}'),
+            self.check('retentionInDays', 50),
+            self.check('totalRetentionInDays', 80),
+        ])
+
+        self.cmd('monitor log-analytics workspace table delete -g {rg} -n {table_name} --workspace-name {ws_name} -y')
+
+        self.cmd('monitor log-analytics workspace table search-job create -n {table2_name} -g {rg} --workspace-name {ws_name} --retention-time 50 --total-retention-time 80 --start-search-time "2021-08-01 05:29:18" --end-search-time "2021-08-02 05:29:18" --search-query "Heartbeat" --limit 1', checks=[
+            self.check('name', '{table2_name}'),
+            self.check('schema.searchResults.query', 'Heartbeat'),
+            self.check('schema.searchResults.limit', 1),
+            self.check('schema.searchResults.sourceTable', "Heartbeat"),
+        ])
