@@ -8,8 +8,8 @@
 
 def cf_netappfiles(cli_ctx, *kwargs):
     from azure.cli.core.commands.client_factory import get_mgmt_service_client
-    from azure.mgmt.netapp import AzureNetAppFilesManagementClient
-    return get_mgmt_service_client(cli_ctx, AzureNetAppFilesManagementClient)
+    from azure.mgmt.netapp import NetAppManagementClient
+    return get_mgmt_service_client(cli_ctx, NetAppManagementClient)
 
 
 def accounts_mgmt_client_factory(cli_ctx, _):
