@@ -39,8 +39,8 @@ CREDENTIAL_WARNING = (
 
 logger = get_logger(__name__)
 
-SCOPE_WARNING = "In a future release, --scopes argument will become required for creating a role assignment. " \
-                "Please explicitly specify --scopes."
+SCOPE_WARNING = "Starting from Azure CLI 2.35.0, --scopes argument will become required for creating role " \
+                "assignments. Please explicitly specify --scopes."
 
 # pylint: disable=too-many-lines
 
@@ -1874,11 +1874,3 @@ def _random_password(length):
 
     password = first_character + ''.join(password_list)
     return password
-
-
-def list_user_assigned_identities(cmd, resource_group_name=None):
-    from azure.cli.command_modules.role._client_factory import _msi_client_factory
-    client = _msi_client_factory(cmd.cli_ctx)
-    if resource_group_name:
-        return client.user_assigned_identities.list_by_resource_group(resource_group_name)
-    return client.user_assigned_identities.list_by_subscription()
