@@ -135,8 +135,19 @@ class AddServicePrincipalAuthInfo(argparse.Action):
             else:
                 raise ValidationError('Unsupported Key {} is provided for parameter --service-principal. All possible '
                                       'keys are: client-id, object-id, secret'.format(k))
-        if len(d) != 3:
+        if 'client_id' not in d or 'secret' not in d:
             raise ValidationError('Required keys missing for parameter --service-principal. '
-                                  'All possible keys are: client-id, object-id, secret')
+                                  'Required keys are: client-id, secret')
+        if 'principal_id' not in d:
+            from ._utils import run_cli_cmd
+            output = run_cli_cmd('az ad sp show --id {}'.format(d['client_id']))
+            if output:
+                d['principal_id'] = output.get('objectId')
+            else:
+                raise ValidationError('Could not resolve object-id from the given client-id: {}. Please '
+                                      'confirm the client-id and provide the object-id (Enterprise Application) '
+                                      'of the service principal, by using --service-principal client-id=XX '
+                                      'object-id=XX secret=XX'.format(d['client_id']))
+
         d['auth_type'] = 'servicePrincipalSecret'
         return d
