@@ -19,7 +19,8 @@ from azure.cli.command_modules.vm._client_factory import (cf_vm, cf_avail_set, c
                                                           cf_shared_gallery_image_version,
                                                           cf_capacity_reservation_groups, cf_capacity_reservations,
                                                           cf_vmss_run_commands, cf_gallery_application,
-                                                          cf_gallery_application_version)
+                                                          cf_gallery_application_version, cf_restore_point,
+                                                          cf_restore_point_collection)
 from azure.cli.command_modules.vm._format import (
     transform_ip_addresses, transform_vm, transform_vm_create_output, transform_vm_usage_list, transform_vm_list,
     transform_sku_for_table_output, transform_disk_show_table_output, transform_extension_show_table_output,
@@ -227,6 +228,16 @@ def load_command_table(self, _):
         client_factory=cf_capacity_reservations
     )
 
+    restore_point = CliCommandType(
+        operations_tmpl='azure.mgmt.compute.operations#RestorePointsOperations.{}',
+        client_factory=cf_restore_point
+    )
+
+    restore_point_collection = CliCommandType(
+        operations_tmpl='azure.mgmt.compute.operations#RestorePointCollectionsOperations.{}',
+        client_factory=cf_restore_point_collection
+    )
+
     with self.command_group('disk', compute_disk_sdk, operation_group='disks', min_api='2017-03-30') as g:
         g.custom_command('create', 'create_managed_disk', supports_no_wait=True, table_transformer=transform_disk_show_table_output, validator=process_disk_or_snapshot_create_namespace)
         g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
@@ -578,7 +589,7 @@ def load_command_table(self, _):
         g.custom_command('list-shared', 'sig_shared_image_version_list', is_experimental=True)
         g.command('show-shared', 'get', is_experimental=True)
 
-    with self.command_group('sig gallery-application', compute_gallery_application_sdk, client_factory=cf_gallery_application, min_api='2021-07-01') as g:
+    with self.command_group('sig gallery-application', compute_gallery_application_sdk, client_factory=cf_gallery_application, min_api='2021-07-01', operation_group='gallery_applications') as g:
         g.command('list', 'list_by_gallery')
         g.show_command('show', 'get')
         g.custom_command('create', 'gallery_application_create', supports_no_wait=True)
@@ -586,7 +597,7 @@ def load_command_table(self, _):
         g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
         g.wait_command('wait')
 
-    with self.command_group('sig gallery-application version', compute_gallery_application_version_sdk, client_factory=cf_gallery_application_version, min_api='2021-07-01') as g:
+    with self.command_group('sig gallery-application version', compute_gallery_application_version_sdk, client_factory=cf_gallery_application_version, min_api='2021-07-01', operation_group='gallery_application_versions') as g:
         g.command('list', 'list_by_gallery_application')
         g.show_command('show', 'get')
         g.custom_command('create', 'gallery_application_version_create', supports_no_wait=True)
@@ -627,3 +638,19 @@ def load_command_table(self, _):
         g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
         g.custom_show_command('show', 'show_capacity_reservation')
         g.custom_command('list', 'list_capacity_reservation')
+
+    with self.command_group('restore-point', restore_point, client_factory=cf_restore_point, min_api='2021-03-01') as g:
+        g.show_command('show', 'get')
+        g.custom_command('create', 'restore_point_create', supports_no_wait=True)
+        g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
+        g.wait_command('wait')
+
+    with self.command_group('restore-point collection', restore_point_collection, min_api='2021-03-01',
+                            client_factory=cf_restore_point_collection) as g:
+        g.command('list', 'list')
+        g.custom_show_command('show', 'restore_point_collection_show')
+        g.custom_command('create', 'restore_point_collection_create')
+        g.custom_command('update', 'restore_point_collection_update')
+        g.command('delete', 'begin_delete', supports_no_wait=True, confirmation=True)
+        g.command('list-all', 'list_all')
+        g.wait_command('wait')
